@@ -28,10 +28,11 @@ class Rates:
     def __init__(
         self,
         api: str,
-        lat: float,
-        lon: float,
+        lat: float = None,
+        lon: float = None,
         plan: str = None,
         radius: float = None,
+        address: str = None,
         reading: float = None,
     ) -> None:
         """Initialize."""
@@ -41,15 +42,22 @@ class Rates:
         self._plan = plan
         self._radius = radius
         self._reading = reading
+        self._address = address
         self._data = None
 
     def lookup_plans(self) -> Dict[str, Any]:
         """Return the rate plan names per utility in the area."""
         url = f"{BASE_URL}version=latest&format=json"
-        url = f"{url}&api_key={self._api}&lat={self._lat}&lon={self._lon}"
+        url = f"{url}&api_key={self._api}"
         url = f"{url}&sector=Residential"
         if self._radius is not None:
             url = f"{url}&radius={self._radius}"
+
+        if self._address is None:
+            url = f"{url}&lat={self._lat}&lon={self._lon}"
+        else:
+            url = f"{url}&address={self._address}"
+
         rate_names: Dict[str, Any] = {}
 
         result = requests.get(url)
@@ -75,12 +83,17 @@ class Rates:
 
     def update(self) -> None:
         """Update the data."""
-        url = f"{BASE_URL}version=latest&format=json"
-        url = f"{url}&api_key={self._api}&lat={self._lat}&lon={self._lon}"
-        url = f"{url}&sector=Residential&detail=full&getpage={self._plan}"
+        url = f"{BASE_URL}version=latest&format=json&sector=Residential"
+        url = f"{url}&detail=full&api_key={self._api}"
+        url = f"{url}&getpage={self._plan}"
         if self._radius is not None:
             url = f"{url}&radius={self._radius}"
 
+        if self._address is None:
+            url = f"{url}&lat={self._lat}&lon={self._lon}"
+        else:
+            url = f"{url}&address={self._address}"
+
         result = requests.get(url)
         if result.status_code == 404:
             raise UrlNotFound
@@ -124,6 +137,36 @@ class Rates:
             return rate
         return None
 
+    @property
+    def monthly_tier_rate(self) -> float | None:
+        """Return tier rate.
+
+        Requires the monthy accumulative meter reading.
+        """
+        assert self._data is not None
+        if "energyratestructure" in self._data.keys():
+            weekend = False
+            now = datetime.datetime.today()
+            month = now.month - 1
+            hour = now.hour
+            if now.weekday() > 4:
+                weekend = True
+            table = "energyweekdayschedule"
+            if weekend:
+                table = "energyweekendschedule"
+            lookup_table = self._data[table]
+            rate_structure = lookup_table[month][hour]
+            if self._reading:
+                value = float(self._reading)
+                rate_data = self._data["energyratestructure"][rate_structure]
+                for rate in rate_data:
+                    if "max" in rate.keys() and value < (rate["max"] * 29):
+                        return rate["rate"]
+                    continue
+                return rate_data[-1]["rate"]
+            return None
+        return None
+
     @property
     def all_rates(self) -> list | None:
         """Return the current rate."""
